<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'archiver' => 'Enarĥivigi',
	'archiver_concatener_explications' => 'Tiu operacio kunmetos la statistikojn pri la monataj vizitoj :',
	'archiver_concatener_ignorer' => 'La vizitoj malpli ol @nb@-jaraj ne estas koncernataj.',
	'archiver_concatener_par_an' => 'La vizitoj pli ol @nb@-jaraj estos kunmetitaj, por ĉiu artikolo je la unua tago de ĉiu jaro.',
	'archiver_concatener_par_mois' => 'La vizitoj pli ol @nb@-jaraj estos kunmetitaj, por ĉiu artikolo je la unua tago de ĉiu monato.',
	'archiver_et_nettoyer' => 'Enarĥivigi kaj purigi',
	'archiver_nettoyer' => 'Purigi',
	'archiver_nettoyer_explications' => 'Forigas la liniojn pri referencantoj kaj vizitoj, kies artikoloj ne (plu) ekzistas en la datumbazo.',
	'archiver_nettoyer_referers_articles' => 'Purigi la referencantojn de la artikoloj („referers_articles“)',
	'archiver_nettoyer_visites_articles' => 'Purigi la vizitojn de la artikoloj („visites_articles“)',
	'archiver_nombre_lignes' => 'Nombro de linioj',
	'archiver_operation_longue' => 'Tiu operacio povas longe daŭri, ĉefe la unuan fojon.',

	// B
	'bouton_effacer_referers' => 'Forigi nur la enirintajn ligilojn',
	'bouton_effacer_statistiques' => 'Forviŝi ĉiujn statistikojn',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evoluado de la vizitoj<br />@visites@ vizitoj',
	'icone_repartition_actuelle' => 'Afiŝi la nunan distribuon',
	'icone_repartition_visites' => 'Vizitoj-distribuo',
	'icone_statistiques_visites' => 'Statistikoj',
	'info_affichier_visites_articles_plus_visites' => 'Afiŝi la vizitojn por la <b>plej vizititaj artikoloj ekde la komenco :</b>',
	'info_comment_lire_tableau' => 'Kiel legi tiun ĉi tabelon',
	'info_forum_statistiques' => 'Statistikoj pri vizitoj',
	'info_graphiques' => 'Grafikaĵoj',
	'info_popularite_2' => 'populareco de la retejo :',
	'info_popularite_3' => 'populareco : @popularite@ ; vizitoj : @visites@',
	'info_popularite_5' => 'populareco :',
	'info_previsions' => 'prognozoj :',
	'info_question_vignettes_referer' => 'Kiam vi konsultas statistikojn, vi povas havi miniaturan bildeton de la retejoj, el kiuj venas vizitantoj, kondiĉe ke la kromprogramo „Thumbsites“ (miniaturo de retejoj) estas aktiva.',
	'info_question_vignettes_referer_oui' => 'Vidigi de kiuj retejoj venas vizitantoj',
	'info_referer_oui' => 'Aktivigi la kolekton de la referencantoj („referers“)',
	'info_tableaux' => 'Tabeloj',
	'info_visites' => 'vizitoj :',
	'info_visites_plus_populaires' => 'Afiŝi la vizitojn por <b>la plej popularaj artikoloj</b> kaj por <b>la laste publikigitaj artikoloj :</b>',
	'info_zoom' => 'zomo',
	'item_gerer_statistiques' => 'Mastrumi statistikojn de la vizitoj',

	// O
	'onglet_origine_visites' => 'Deveno de la vizitintoj',
	'onglet_repartition_debut' => 'dekomence',
	'onglet_repartition_lang' => 'Distribuo laŭ lingvoj',

	// R
	'resume' => 'Resumo',

	// T
	'texte_admin_effacer_stats' => 'Tiu komando forigas ĉiujn datumojn rilate al la vizit-statistikoj de la retejo, inkluzive la popularecon de la artikoloj.',
	'texte_admin_effacer_toutes_stats' => 'La unua butono forigas ĉiujn statistikojn : vizitojn, artikolan popularecon kaj enirintajn ligilojn.',
	'texte_comment_lire_tableau' => 'La rango de la artikolo, en la klasifiko laŭ populareco, estas indikita en la marĝeno ; la populareco de la artikolo (taksado de la nombro de ĉiutagaj vizitoj, kiun ĝi atingos se la nuna vizit-ritmo tiel daŭros) kaj la nombro de vizitoj ricevitaj de la komenco afiŝiĝas en la veziko kiu aperas kiam la tajpmontrilo superpasas la titolon.',
	'texte_signification' => 'La ruĝaj stangoj reprezentas la sumigitajn datenojn (sumo de la sub-rubrikoj), la helaj stangoj, la nombron de vizitoj por ĉiu rubriko.',
	'titre_evolution_visite' => 'Evoluo de la vizitoj',
	'titre_liens_entrants' => 'Enirintaj ligiloj',
	'titre_page_statistiques' => 'Statistikoj laŭ rubrikoj',
	'titre_page_statistiques_visites' => 'Statistikoj de la vizitoj',

	// V
	'visites_journalieres' => 'Taga vizitnombro',
	'visites_mensuelles' => 'Monata vizitnombro',
];
